@@ -310,12 +310,18 @@ class Credit(TMDbReload):
         self.popularity = self._parse(attrs=dict_check("person", "popularity"), value_type="int")
         self.profile_path = self._parse(attrs=dict_check("person", "profile_path"))
         self.profile_url = self._image_url(self.profile_path)
-        if self.media_type == "movie":
-            self.movie = self._parse(attrs="media", value_type="movie")
-        elif self.media_type == "tv":
-            self.tv_show = self._parse(attrs="media", value_type="tv")
-            self.seasons = self._parse(attrs=["media", "seasons"], value_type="season", is_list=True)
-            self.episodes = self._parse(attrs=["media", "episodes"], value_type="episode", is_list=True)
+        if "media" in self._data:
+            if self.media_type == "movie":
+                self.movie = self._parse(attrs="media", value_type="movie")
+            elif self.media_type == "tv":
+                self.tv_show = self._parse(attrs="media", value_type="tv")
+                self.seasons = self._parse(attrs=["media", "seasons"], value_type="season", is_list=True)
+                self.episodes = self._parse(attrs=["media", "episodes"], value_type="episode", is_list=True)
+        elif "credit_id" in self._data:
+            if self.media_type == "movie":
+                self.movie = self._tmdb.movie(self._parse(attrs="id", value_type="int"), load=False)
+            elif self.media_type == "tv":
+                self.tv_show = self._tmdb.tv_show(self._parse(attrs="id", value_type="int"), load=False)
 
     def _full_load(self):
         return self._api.credits_get_details(self.id)
@@ -440,12 +446,14 @@ class Keyword(TMDbReload):
         Attributes:
             id (int): Keyword ID.
             name (str): Keyword Name.
-            movies (List[:class:`~tmdbapis.objs.reload.Movie`]): Keyword Movies.
-            tv_shows (List[:class:`~tmdbapis.objs.reload.TVShow`]): Keyword TV Shows.
+            movies (:class:`~tmdbapis.objs.pagination.DiscoverMovies`): Keyword Movies.
+            tv_shows (:class:`~tmdbapis.objs.pagination.DiscoverTVShows`): Keyword TV Shows.
     """
 
     def _load(self, data):
         super()._load(data)
+        self._movies = None
+        self._tv_shows = None
         self.id = self._parse(attrs="id", value_type="int")
         self.name = self._parse(attrs="name")
         self._finish(self.name)
@@ -455,11 +463,15 @@ class Keyword(TMDbReload):
 
     @property
     def movies(self):
-        return self._api.discover_movie_discover(with_keywords=self.id)
+        if not self._movies:
+            self._movies = self._tmdb.discover_movies(with_keywords=self.id)
+        return self._movies
 
     @property
     def tv_shows(self):
-        return self._api.discover_tv_discover(with_keywords=self.id)
+        if not self._tv_shows:
+            self._tv_shows = self._tmdb.discover_tv_shows(with_keywords=self.id)
+        return self._tv_shows
 
 
 class Movie(TMDbReload, Favorite, Rate, Watchlist):
@@ -614,11 +626,12 @@ class Network(TMDbReload):
             logo_url (str): Logo Full URL.
             logos (List[:class:`~tmdbapis.objs.image.Logo`]): List of other Logos for the Network.
             name (str): Network Name.
-            tv_shows (List[:class:`~tmdbapis.objs.reload.TVShow`]): Network TV Shows.
+            tv_shows (:class:`~tmdbapis.objs.pagination.DiscoverTVShows`): Network TV Shows.
     """
 
     def _load(self, data):
         super()._load(data)
+        self._tv_shows = None
         self.alternative_names = self._parse(attrs=["alternative_names", "results"],
                                              value_type="alternative_name", is_list=True)
         self.country = self._parse(attrs="origin_country", value_type="country")
@@ -636,7 +649,9 @@ class Network(TMDbReload):
 
     @property
     def tv_shows(self):
-        return self._api.discover_tv_discover(with_networks=self.id)
+        if not self._tv_shows:
+            self._tv_shows = self._tmdb.discover_tv_shows(with_networks=self.id)
+        return self._tv_shows
 
 
 class Person(TMDbReload):
